Function keccak256_uncached

pub fn keccak256_uncached<T: AsRef<[u8]>>(bytes: T) -> B256
Simple interface to the Keccak-256 hash function.

This function always computes the hash directly without using the cache.

Does not use the cache even if the keccak-cache feature is enabled.